@@ -163,7 +163,7 @@ class Yolov7:
     
     
     def train(self, cuda: bool = True, distributed: bool = False, sync_bn: bool = False,
-              fp16: bool = False, anchors_path: str = 'yolovxx/yolov7pytorch/model_data/yolo_anchors.txt', pretrained: bool = False,
+              fp16: bool = False, anchors_path: str = 'yolovxx/yolovxx/yolov7pytorch/model_data/yolo_anchors.txt', pretrained: bool = False,
               model_path: str = "", phi: str = "l", input_shape: list = [640, 640],
               save_dir: str = 'logs', save_period: int = 10, eval_flag: bool= True,
               eval_period: int = 10, num_workers: int = 4) -> None:
